Index: main/manager.c
===================================================================
--- main/manager.c	(revision 58853)
+++ main/manager.c	(working copy)
@@ -453,6 +453,41 @@
 	return RESULT_SUCCESS;
 }
 
+static int handle_dumphtml(int fd, int argc, char *argv[])
+{
+	FILE *htmlfile;
+	struct manager_action *cur;
+
+	if ((argc < 3))
+		return RESULT_SHOWUSAGE;
+
+	if (!(htmlfile = fopen(argv[2], "wt"))) {
+		ast_cli(fd, "Could not create file '%s'\n", argv[2]);
+		return RESULT_SHOWUSAGE;
+	}
+
+	fprintf(htmlfile, "<HTML>\n<HEAD>\n<TITLE>AMI Commands</TITLE>\n</HEAD>\n");
+	fprintf(htmlfile, "<BODY>\n<CENTER><B><H1>AMI Commands</H1></B></CENTER>\n\n");
+
+
+	fprintf(htmlfile, "<TABLE BORDER=\"0\" CELLSPACING=\"10\">\n");
+
+	for (cur = first_action; cur; cur = cur->next) {
+		fprintf(htmlfile, "<TR><TD><TABLE BORDER=\"1\" CELLPADDING=\"5\" WIDTH=\"100%%\">\n");
+		fprintf(htmlfile, "<TR><TH ALIGN=\"CENTER\"><B>%s</B></TH></TR>\n", cur->action);
+
+		fprintf(htmlfile, "<TR><TD ALIGN=\"CENTER\">%s</TD></TR>\n", cur->description?cur->description:cur->synopsis);
+		fprintf(htmlfile, "</TABLE></TD></TR>\n\n");
+	}
+
+	fprintf(htmlfile, "</TABLE>\n</BODY>\n</HTML>\n");
+	fclose(htmlfile);
+	ast_cli(fd, "AMI HTML Commands Dumped to: %s\n", argv[2]);
+	return RESULT_SUCCESS;
+}
+
+
+
 static int handle_showmanager(int fd, int argc, char *argv[])
 {
 	struct ast_manager_user *user = NULL;
@@ -585,6 +620,10 @@
 "Usage: manager show commands\n"
 "	Prints a listing of all the available Asterisk manager interface commands.\n";
 
+static char dumphtml_help[] =
+"Usage: manager dumphtml <filename>\n"
+"       Dumps the agi command list in html format to given filename\n";
+
 static char showmanconn_help[] = 
 "Usage: manager show connected\n"
 "	Prints a listing of the users that are currently connected to the\n"
@@ -648,6 +687,10 @@
 	{ { "manager", "show", "user", NULL },
 	handle_showmanager, "Display information on a specific manager user",
 	showmanager_help, NULL, NULL },
+	
+	{ { "manager", "dumphtml", NULL, NULL },
+	handle_dumphtml, "Dumps all manager commands in HTML",
+	dumphtml_help, NULL, NULL },	
 };
 
 static void unuse_eventqent(struct eventqent *e)
@@ -2876,3 +2919,4 @@
 	manager_event(EVENT_FLAG_SYSTEM, "Reload", "Message: Reload Requested\r\n");
 	return init_manager();
 }
+
